@@ -76,6 +76,7 @@ typedef struct {
 	int			fcs;
 	int			clock;
 	unsigned char		lcode;
+	unsigned char		disc_cfg_timeout;
 } sdla_te3_cfg_t;
 
 typedef struct {
@@ -105,11 +106,13 @@ typedef struct {
 #if defined(WAN_KERNEL)
 
 typedef struct {
+	unsigned long	critical;
 	int dummy;
 	u_int8_t	cpld_cntrl;
 	u_int8_t	cpld_status;
 	u_int8_t	e3_lb_ctrl;
 	u_int8_t	e3_connect_delay;
+	wan_ticks_t	disc_timeout;		
 } sdla_te3_param_t;
 
 int sdla_te3_iface_init(void *p_fe_iface);
